@@ -47,15 +47,14 @@ def add_alarm_status(
         )
         print(new_alarm_status)
     """
-    if (name == ""):
-        print ("you cant leave the name parameter empty")
-    elif name!=str:
-        print ("the input must be a text, example name=''new name''")
-    else:
-        alarm_status_input = AddAlarmStatusInput(name=name)        
+    alarm_status_input = AddAlarmStatusInput(name=name)
+    if (len(name) != 0):
         result = addAlarmStatus.execute(client, input=alarm_status_input)
         return alarmStatus(name=result.name, id=result.id)
-        
+    else:
+        print ("you cant leave the name parameter empty")
+
+
 def edit_alarm_status(
     client: SymphonyClient,
     alarm_status: alarmStatus,
